| Title: | Show the Global Environment Some Appreciation |
|---|---|
| Description: | In times as trying as these, some extra care is sorely needed for the treatment of one's global variables. A constructive suggestion was made in <https://twitter.com/Obsidiandy/status/1256667469852393474>, and this package aims to pblige. |
| Authors: | Dirk Eddelbuettel |
| Maintainer: | Dirk Eddelbuettel <[email protected]> |
| License: | GPL (>= 2) |
| Version: | 0.0.1 |
| Built: | 2026-05-27 10:46:57 UTC |
| Source: | https://github.com/eddelbuettel/safy |
In times as trying as these, some extra care is sorely needed for the treatment of one's global variables. A constructive suggestion was made in <https://twitter.com/Obsidiandy/status/1256667469852393474>, and this package aims to pblige.
Index of help topics:
safy-package Show the Global Environment Some Appreciation
Dirk Eddelbuettel <[email protected]>
Dirk Eddelbuettel